MarginRankingLoss
=================

.. currentmodule:: pykeen.losses

.. autoclass:: MarginRankingLoss
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~MarginRankingLoss.hpo_default
      ~MarginRankingLoss.synonyms

   .. rubric:: Attributes Documentation

   .. autoattribute:: hpo_default
   .. autoattribute:: synonyms
